# dewloosh.core

This package contains common developer utilities to support other `dewloosh` packages.

**The package in alpa stage, under development**. Expected date of the first stable release is 2022-Q2.

